:orphan:

Gallery
=======


.. raw:: html

    <div class="sphx-glr-thumbnails">

.. thumbnail-parent-div-open

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates how to retrieve the list of variables stored in a TileDB array using the GEDIProvider class from the gedidb package. The output is a pandas.DataFrame containing variable names, descriptions, and metadata.">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_get_variable_list_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_get_variable_list.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Retrieve List of Variables in TileDB Array</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates how to authenticate with the NASA EarthData API using the EarthDataAuthenticator class. The authentication process involves managing netrc and cookie files to ensure seamless automated login.">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_authentification_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_authentification.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Authenticating with NASA EarthData API</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates how to use the gedidb library to process GEDI granules  with different parallel engines, such as concurrent.futures.ThreadPoolExecutor and dask.distributed.Client.">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_data_processor_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_data_processor.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">GEDIProcessor example with different parallel engines</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates how to create a regional TileDB array for the Amazon  by modifying the data_config.yml file to adjust the spatial range based on  a bounding box extracted from a GeoJSON file.">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_regional_tileDBdatabase_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_regional_tileDBdatabase.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Creating a Regional TileDB Array for the Amazon</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates how to use the GEDIProvider class to query and retrieve GEDI data stored in TileDB arrays. We will:">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_data_provider_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_data_provider.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Querying Processed GEDI Data from TileDB</div>
    </div>


.. thumbnail-parent-div-close

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/get_variable_list
   /auto_examples/authentification
   /auto_examples/data_processor
   /auto_examples/regional_tileDBdatabase
   /auto_examples/data_provider


.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-gallery

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download all examples in Python source code: auto_examples_python.zip </auto_examples/auto_examples_python.zip>`

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip </auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
